.. _recipe_asr.fermisurface:

asr.fermisurface
================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.fermisurface`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.fermisurface.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.fermisurface

or as a python module

.. code-block:: console

   $ python -m asr.fermisurface

Detailed description
--------------------
Fermi surfaces.

Steps
-----


asr.fermisurface
^^^^^^^^^^^^^^^^
.. autofunction:: asr.fermisurface.main
   